{% extends "base.html" %}
{% block title %}404 - özgürsözlük{% endblock %}
{% block meta %}
    <meta name="title" content="404 - özgürsözlük">
    <meta name="description" content="{{ description }}">
{% endblock %}
{% block main %}
    <nav>{% include "navigation.html" %}</nav>
    <div class="topic" style="text-align: center; padding-top: 3rem;">
        <p>
            page not found
            </br>
            what you were looking for is just not there
            </br></br>
            <a href="{{ url_for('search', q='404') }}">go somewhere nice</a>
        </p>
    </div>
{% endblock %}
