{% extends "base.html" %}
{% block title %}{{ topic.title }} {% if p > 1 %}- page: {{ p }}{% endif %} - özgürsözlük{% endblock %}
{% block meta %}
    <meta name="title" content="özgürsözlük">
    <meta name="description" content="{{ topic.title }}">
{% endblock %}
{% block main %}
    <nav>{% include "navigation.html" %}</nav>
    <div class="topic">
        <div class="info">
            <div>
                <p>
                    {{ topic.title }} - şükela:
                    {% if topic.nice %}
                        <a href="{{ url_for('topic', path=topic.path) }}"><b>nice</b></a>
                    {% else %}
                        <a href="{{ url_for('topic', path=topic.path, a='nice') }}">
                            nice
                        </a>
                    {% endif %}
                </p>
            </div>
            {% include "paginate.html" %}
        </div>
        {% for entry in topic.entrys %}
            {% from "macros.html" import render_entry %}
            {{ render_entry(entry, True) }}
        {% endfor %}
        <div class="info" style="padding-top: 0;">
            <div></div>
            {% include "paginate.html" %}
        </div>
    </div>
{% endblock %}
