{% extends "base.html" %}
{% block title %}donate - özgürsözlük{% endblock %}
{% block meta %}
    <meta name="title" content="donate - özgürsözlük">
    <meta name="description" content="{{ description }}">
{% endblock %}
{% block main %}
    <div class="topic donate">
        <p>
            donate to the developer <3
            </br></br>
            <b>bitcoin [btc]:</b></br>
            3EEMjJwf1RE48iziynYYPweV1nsWguTUUz
        </p>
        </b>
        <img src="{{ url_for('static', filename='btc.jpeg') }}" width="200">
    </div>
{% endblock %}
