{% extends "base.html" %}
{% block title %}debe - özgürsözlük{% endblock %}
{% block meta %}
    <meta name="title" content="debe - özgürsözlük">
    <meta name="description" content="{{ description }}">
{% endblock %}
{% block main %}
    <nav>{% include "navigation.html" %}</nav>
    <div class="topic">
        <div class="info">
            <div>
                <p>debe - <a href="/">gündem</a></p>
            </div>
            <div></div>
        </div>
        <div class="entry_wrapper">
            {% for entry in debe %}
                <a class="entry" style="text-decoration: none;" href="{{ url_for('entry', id=entry.id) }}">
                    <div>
                        <div>{{ entry.title }}</div>
                    </div>
                </a>
            {% endfor %}
        </div>
    </div>
{% endblock %}
